/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.token;

import java.util.Dictionary;
import java.util.Hashtable;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.html.AbstractCreateToken;
import org.opengion.fukurou.util.StringUtil;
import com.akamai.token_v2.*;

// import com.akamai.authentication.URLToken.URLTokenFactory;

/**
 * アカマイのトークンを付加するためのプラグインです。
 * 
 * 以下のシステムリソース設定を行う事でパラメータの変更が可能です。
 * AKAMAI_TOKEN_NAME:トークン名称(初期値：akminame)
 * AKAMAI_ENCRYPTION:トークン作成時暗号化キー(初期値：enckey)
 * 
 * このプラグイン利用にはcom.akamai.token_v2.*;が必要です。
 *
 * @og.group 画面表示
 * @og.rev 5.8.2.2 (2014/12/19) 
 *
 * @version  5.0
 * @author	 Takahashi Masakazu
 * @since    JDK5.0,
 */
public class CreateToken_Akamai extends AbstractCreateToken {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.8.2.1 (2014/12/13)" ;
	
	private static final String AKAMAI_TOKEN_NAME = StringUtil.nval(HybsSystem.sys( "AKAMAI_TOKEN_NAME" ),"akminame");
	private static final String AKAMAI_ENCRYPTION = StringUtil.nval(HybsSystem.sys( "AKAMAI_ENCRYPTION" ),"enckey");
	
//	private static final URLTokenFactory fact = new URLTokenFactory();
	private Dictionary token_config;


	/**
	 * アカマイのトークンを付けたURLを返します。
	 *
	 *
	 * @return  URL
	 */
	@Override
	public String  generateURL( final String inURL, final long time, final String user, final String[] param ){
		long wn = ( time - System.currentTimeMillis() ) /1000;
//		return fact.generateURL(inURL, null, wn , AKAMAI_SALT, System.currentTimeMillis()); 

		token_config = new Hashtable();
		token_config.put("token_name", new String( AKAMAI_TOKEN_NAME ));
		token_config.put("key", new String( AKAMAI_ENCRYPTION ));
		token_config.put("window_seconds", new String( Long.toString( wn ) ));
		token_config.put("url", new String( inURL ));
		try{
			String tkn =  AkamaiToken.generateToken( token_config );
			
			return tkn;
		}
		catch( Exception ex ){
			ex.printStackTrace();
			return inURL;
		}
	}	

}
